@@ -6,7 +6,7 @@ require 'puppet/parser/compiler'
 class Puppet::Application::Lookup < Puppet::Application
 
   RUN_HELP = "Run 'puppet lookup --help' for more details".freeze
-  DEEP_MERGE_OPTIONS = '--knock-out-prefix, --sort-merged-arrays, --unpack-arrays, and --merge-hash-arrays'.freeze
+  DEEP_MERGE_OPTIONS = '--knock-out-prefix, --sort-merged-arrays, and --merge-hash-arrays'.freeze
 
   run_mode :master
 
@@ -35,10 +35,6 @@ class Puppet::Application::Lookup < Puppet::Application
 
   option('--sort-merge-arrays')
 
-  option('--unpack-arrays DELIMITER') do |arg|
-    options[:unpack_arrays] = arg
-  end
-
   option('--merge-hash-arrays')
 
   option('--explain')
@@ -124,7 +120,7 @@ USAGE
 -----
 puppet lookup [--help] [--type <TYPESTRING>] [--merge unique|hash|deep]
   [--knock-out-prefix <PREFIX-STRING>] [--sort-merged-arrays]
-  [--unpack-arrays <STRING-VALUE>] [--merge-hash-arrays] [--explain]
+  [--merge-hash-arrays] [--explain]
   [--default <VALUE>] [--node <NODE-NAME>] [--facts <FILE>]
   [--compile]
   [--render-as s|json|yaml|binary|msgpack] <keys>
@@ -172,10 +168,6 @@ the puppet lookup function linked to above.
   Can be used with the 'deep' merge strategy. When this flag is used all
   merged arrays will be sorted.
 
-* --unpack-arrays <STRING-VALUE>
-  Can be used with the 'deep' merge strategy. Specify a string value used
-  as a deliminator to join all array values and then split them again.
-
 * --merge-hash-arrays
   Can be used with the 'deep' merge strategy. When this flag is used arrays
   and hashes will be merged.
@@ -225,7 +217,7 @@ EXAMPLE
   If you wanted to get the first value found for 'key_name_one' and 'key_name_two'
   within the scope of the agent.local node while merging values and knocking out
   the prefix 'foo' while merging, you would call lookup like this:
-  $ puppet lookup --node agent.local --merge deep --knock_out_prefix foo key_name_one key_name_two
+  $ puppet lookup --node agent.local --merge deep --knock-out-prefix foo key_name_one key_name_two
 
   If you wanted to lookup 'key_name' within the scope of the agent.local node,
   and return a default value of 'bar' if nothing was found, you would call
@@ -251,7 +243,7 @@ Copyright (c) 2015 Puppet Labs, LLC Licensed under the Apache 2.0 License
     #  raise "No node was given via the '--node' flag for the scope of the lookup.\n#{RUN_HELP}"
     #end
 
-    if (options[:sort_merge_arrays] || options[:merge_hash_arrays] || options[:prefix] || options[:unpack_arrays]) && options[:merge] != 'deep'
+    if (options[:sort_merge_arrays] || options[:merge_hash_arrays] || options[:prefix]) && options[:merge] != 'deep'
       raise "The options #{DEEP_MERGE_OPTIONS} are only available with '--merge deep'\n#{RUN_HELP}"
     end
 
@@ -275,10 +267,6 @@ Copyright (c) 2015 Puppet Labs, LLC Licensed under the Apache 2.0 License
           merge_options.merge!({'knockout_prefix' => options[:prefix]})
         end
 
-        if options[:unpack_arrays]
-          merge_options.merge!({'unpack_arrays' => options[:unpack_arrays]})
-        end
-
       else
         merge_options = {'strategy' => merge}
       end
