@@ -10,6 +10,8 @@ module Puppet
   #
   # @api public
   module Pops
+    require 'semantic'
+
     require 'puppet/pops/patterns'
     require 'puppet/pops/utils'
 
@@ -27,13 +29,16 @@ module Puppet
     require 'puppet/pops/validation'
     require 'puppet/pops/issue_reporter'
     require 'puppet/pops/lookup'
+    require 'puppet/pops/lookup/interpolation'
     require 'puppet/pops/lookup/invocation'
+    require 'puppet/pops/lookup/sub_lookup'
     require 'puppet/pops/lookup/explainer'
 
     require 'puppet/pops/model/model'
 
     # (the Types module initializes itself)
     require 'puppet/pops/types/types'
+    require 'puppet/pops/types/string_converter'
 
     require 'puppet/pops/merge_strategy'
 
@@ -77,6 +82,7 @@ module Puppet
     end
 
     module Evaluator
+      require 'puppet/pops/evaluator/literal_evaluator'
       require 'puppet/pops/evaluator/callable_signature'
       require 'puppet/pops/evaluator/runtime3_converter'
       require 'puppet/pops/evaluator/runtime3_support'
